From 2a26790808f26a29dc69443b4b0735d1f981c43a Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Mon, 17 Jun 2024 09:29:53 +0200
Subject: [PATCH v2 08/10] Remove useless extern keywords

An extern keyword on a function definition (not declaration) is
useless and not the normal style.

Discussion: https://www.postgresql.org/message-id/flat/e0a62134-83da-4ba4-8cdb-ceb0111c95ce@eisentraut.org
---
 src/backend/backup/basebackup_incremental.c | 4 ++--
 src/backend/storage/file/fd.c               | 2 +-
 src/bin/pg_basebackup/bbstreamer_inject.c   | 2 +-
 src/bin/pg_basebackup/bbstreamer_tar.c      | 4 ++--
 4 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/backend/backup/basebackup_incremental.c b/src/backend/backup/basebackup_incremental.c
index b6cfeb6926a..cf2e9eb02cf 100644
--- a/src/backend/backup/basebackup_incremental.c
+++ b/src/backend/backup/basebackup_incremental.c
@@ -944,7 +944,7 @@ GetFileBackupMethod(IncrementalBackupInfo *ib, const char *path,
  * number of blocks. The header is rounded to a multiple of BLCKSZ, but
  * only if the file will store some block data.
  */
-extern size_t
+size_t
 GetIncrementalHeaderSize(unsigned num_blocks_required)
 {
 	size_t		result;
@@ -972,7 +972,7 @@ GetIncrementalHeaderSize(unsigned num_blocks_required)
 /*
  * Compute the size for an incremental file containing a given number of blocks.
  */
-extern size_t
+size_t
 GetIncrementalFileSize(unsigned num_blocks_required)
 {
 	size_t		result;
diff --git a/src/backend/storage/file/fd.c b/src/backend/storage/file/fd.c
index a7c05b0a6fd..3944321ff37 100644
--- a/src/backend/storage/file/fd.c
+++ b/src/backend/storage/file/fd.c
@@ -4020,7 +4020,7 @@ check_debug_io_direct(char **newval, void **extra, GucSource source)
 	return result;
 }
 
-extern void
+void
 assign_debug_io_direct(const char *newval, void *extra)
 {
 	int		   *flags = (int *) extra;
diff --git a/src/bin/pg_basebackup/bbstreamer_inject.c b/src/bin/pg_basebackup/bbstreamer_inject.c
index 2191cf47772..194026b56e9 100644
--- a/src/bin/pg_basebackup/bbstreamer_inject.c
+++ b/src/bin/pg_basebackup/bbstreamer_inject.c
@@ -61,7 +61,7 @@ static const bbstreamer_ops bbstreamer_recovery_injector_ops = {
  * zero-length standby.signal file, dropping any file with that name from
  * the archive.
  */
-extern bbstreamer *
+bbstreamer *
 bbstreamer_recovery_injector_new(bbstreamer *next,
 								 bool is_recovery_guc_supported,
 								 PQExpBuffer recoveryconfcontents)
diff --git a/src/bin/pg_basebackup/bbstreamer_tar.c b/src/bin/pg_basebackup/bbstreamer_tar.c
index 6df3b97f9cb..9137d17ddc1 100644
--- a/src/bin/pg_basebackup/bbstreamer_tar.c
+++ b/src/bin/pg_basebackup/bbstreamer_tar.c
@@ -89,7 +89,7 @@ static const bbstreamer_ops bbstreamer_tar_terminator_ops = {
  * specified by 'next' will receive a series of typed chunks, as per the
  * conventions described in bbstreamer.h.
  */
-extern bbstreamer *
+bbstreamer *
 bbstreamer_tar_parser_new(bbstreamer *next)
 {
 	bbstreamer_tar_parser *streamer;
@@ -352,7 +352,7 @@ bbstreamer_tar_parser_free(bbstreamer *streamer)
  * chunks (i.e. not BBSTREAMER_UNKNOWN). See also the comments for
  * bbstreamer_tar_parser_content.
  */
-extern bbstreamer *
+bbstreamer *
 bbstreamer_tar_archiver_new(bbstreamer *next)
 {
 	bbstreamer_tar_archiver *streamer;
-- 
2.45.2

